@@ -172,13 +172,21 @@ class RAMClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ram/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ram/client/#close)
+        """
+
     def create_resource_share(
         self,
         *,
         name: str,
         resourceArns: Sequence[str] = ...,
         principals: Sequence[str] = ...,
-        tags: Sequence["TagTypeDef"] = ...,
+        tags: Sequence[TagTypeDef] = ...,
         allowExternalPrincipals: bool = ...,
         clientToken: str = ...,
         permissionArns: Sequence[str] = ...
@@ -317,7 +325,7 @@ class RAMClient(BaseClient):
         resourceShareArns: Sequence[str] = ...,
         resourceShareStatus: ResourceShareStatusType = ...,
         name: str = ...,
-        tagFilters: Sequence["TagFilterTypeDef"] = ...,
+        tagFilters: Sequence[TagFilterTypeDef] = ...,
         nextToken: str = ...,
         maxResults: int = ...,
         permissionArn: str = ...
@@ -452,9 +460,7 @@ class RAMClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ram/client/#reject_resource_share_invitation)
         """
 
-    def tag_resource(
-        self, *, resourceShareArn: str, tags: Sequence["TagTypeDef"]
-    ) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceShareArn: str, tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Adds the specified tag keys and values to the specified resource share.
 
