@@ -31,8 +31,7 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import (
     ResourceOwnerType,
@@ -72,7 +71,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class GetResourcePoliciesPaginator(Boto3Paginator):
+class GetResourcePoliciesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators/#getresourcepoliciespaginator)
@@ -83,7 +82,7 @@ class GetResourcePoliciesPaginator(Boto3Paginator):
         *,
         resourceArns: Sequence[str],
         principal: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetResourcePoliciesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.GetResourcePolicies.paginate)
@@ -91,7 +90,7 @@ class GetResourcePoliciesPaginator(Boto3Paginator):
         """
 
 
-class GetResourceShareAssociationsPaginator(Boto3Paginator):
+class GetResourceShareAssociationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators/#getresourceshareassociationspaginator)
@@ -105,7 +104,7 @@ class GetResourceShareAssociationsPaginator(Boto3Paginator):
         resourceArn: str = ...,
         principal: str = ...,
         associationStatus: ResourceShareAssociationStatusType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetResourceShareAssociationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations.paginate)
@@ -113,7 +112,7 @@ class GetResourceShareAssociationsPaginator(Boto3Paginator):
         """
 
 
-class GetResourceShareInvitationsPaginator(Boto3Paginator):
+class GetResourceShareInvitationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators/#getresourceshareinvitationspaginator)
@@ -124,7 +123,7 @@ class GetResourceShareInvitationsPaginator(Boto3Paginator):
         *,
         resourceShareInvitationArns: Sequence[str] = ...,
         resourceShareArns: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetResourceShareInvitationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations.paginate)
@@ -132,7 +131,7 @@ class GetResourceShareInvitationsPaginator(Boto3Paginator):
         """
 
 
-class GetResourceSharesPaginator(Boto3Paginator):
+class GetResourceSharesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.GetResourceShares)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators/#getresourcesharespaginator)
@@ -145,9 +144,9 @@ class GetResourceSharesPaginator(Boto3Paginator):
         resourceShareArns: Sequence[str] = ...,
         resourceShareStatus: ResourceShareStatusType = ...,
         name: str = ...,
-        tagFilters: Sequence["TagFilterTypeDef"] = ...,
+        tagFilters: Sequence[TagFilterTypeDef] = ...,
         permissionArn: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetResourceSharesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.GetResourceShares.paginate)
@@ -155,7 +154,7 @@ class GetResourceSharesPaginator(Boto3Paginator):
         """
 
 
-class ListPrincipalsPaginator(Boto3Paginator):
+class ListPrincipalsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.ListPrincipals)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators/#listprincipalspaginator)
@@ -169,7 +168,7 @@ class ListPrincipalsPaginator(Boto3Paginator):
         principals: Sequence[str] = ...,
         resourceType: str = ...,
         resourceShareArns: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListPrincipalsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.ListPrincipals.paginate)
@@ -177,7 +176,7 @@ class ListPrincipalsPaginator(Boto3Paginator):
         """
 
 
-class ListResourcesPaginator(Boto3Paginator):
+class ListResourcesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.ListResources)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators/#listresourcespaginator)
@@ -192,7 +191,7 @@ class ListResourcesPaginator(Boto3Paginator):
         resourceArns: Sequence[str] = ...,
         resourceShareArns: Sequence[str] = ...,
         resourceRegionScope: ResourceRegionScopeFilterType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListResourcesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#RAM.Paginator.ListResources.paginate)
